# Anilistpy ![anilistpy](https://avatars3.githubusercontent.com/u/75199724?s=30&v=4)

![Test](https://github.com/anilistpy/anilistpy/workflows/Test/badge.svg)
[![CodeFactor](https://www.codefactor.io/repository/github/anilistpy/anilistpy/badge)](https://www.codefactor.io/repository/github/anilistpy/anilistpy)
![PyPI - Downloads](https://img.shields.io/pypi/dm/anilistpy)
[![pypi verison](https://img.shields.io/pypi/v/anilistpy.svg)](https://pypi.org/project/anilistpy/)
[![GitHub license](https://img.shields.io/github/license/anilistpy/anilistpy)](https://github.com/anilistpy/anilistpy/blob/master/license)

An easy to use python3 wrapper for anilist.co APIv2 (UNOFFICIAL)

# Installing

## Installing from pypi
```
pip install anilistpy
```

## Build Requirements:

- Rust Toolchain (rustc cargo) 
- Python Toolchain (pip wheel setuptools setuptools-rust)

## NOTE FOR WINDOWS/MAC USERS:

i will only provide binaries for gnu/linux starting from v0.1.x, if you want to use this library on these platforms, you will have to compile from source or install v0.0.5.x, which wont get new features but get bug fixes.

 
Documenation and Examples [here](https://anilistpy.github.io/) 
(note: the Documenation is not complete, if you need help make a issue)

# Change log 0.5.x -> 0.1.x

- moving to rust for better performance 

![agpl3](https://upload.wikimedia.org/wikipedia/commons/thumb/0/06/AGPLv3_Logo.svg/200px-AGPLv3_Logo.svg.png)
